==> HoneydCenter-1.0.tgz: HoneydCenter/__init__.py <==
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
# ======================================================================
__version__= '1.0'


from Globals import HTMLFile,MessageDialog
from ImageFile import ImageFile  
import zProduct





#html-add-form
manage_addzProductForm = HTMLFile('dtml/add_form', globals())

#action for html-add-form
def manage_addzProduct(self, id='',title='', REQUEST=None, submit=None):
    """Add a Zope product """
    if id=='':
        return MessageDialog( title='Error', message='Please enter an id!', action = REQUEST['URL1']+'/add_form',)
    ob=zProduct.zProductDocument(id, title)
    ob.title=title
    id=self._setObject(id, ob)
    if REQUEST is not None:
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        if submit=="Add": u="%s/%s" % (u,quote(id))
        REQUEST.RESPONSE.redirect(u+'/manage_main')
    return 'Nothing'




# Load images from disk and make them accessible
misc_={
       'icon':   ImageFile('img/icon.png',globals()),
      }  




def initialize(context): 
    """Initialize the product."""  
    try: 
        context.registerClass(
            zProduct.zProductDocument,
            #permission='Add product', #automatically included; I don't need to specify it
            constructors = (                 
                manage_addzProductForm,  #html file; html-form has action next constructor
                manage_addzProduct),     #constructor caled from html-form (action)                                            
            )
        context.registerBaseClass(zProduct.zProductDocument)

    except:
        import sys, traceback, string
        type, val, tb = sys.exc_info()
        sys.stderr.write(string.join(traceback.format_exception(type, val, tb), ''))
        del type, val, tb

    context.registerHelp()
    context.registerHelpTitle(zProduct.ProductName)

==> HoneydCenter-1.1.tgz: HoneydCenter/__init__.py <==
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
# ======================================================================
__version__= '1.1'


from Globals import HTMLFile,MessageDialog
from ImageFile import ImageFile  
import zProduct
import Products.SQLForms

methods={
    #I need this to make visible ScriptsIDs from dtml
    'ReturnIDs': Products.SQLForms.SQLForms.ReturnIDs,
    }
	    
	     


#html-add-form
manage_addzProductForm = HTMLFile('dtml/add_form', globals())

#action for html-add-form
def manage_addzProduct(self, id='', title='', database='', REQUEST=None, submit=None):
    """Add a Zope product """
    if id=='':
        return MessageDialog( title='Error', message='Please enter an id!', action = REQUEST['URL1']+'/add_form',)
    if database=='':
        return MessageDialog( title='Error', message='''
        Please select a database adaptor!<br>
        If no database adaptors available, please add some!
	''', action = REQUEST['URL1']+'/add_form',)
    urlupdate=str(self.REQUEST.PARENTS[0].absolute_url())+'/'+str(id)+'/updatedb'
    ob=zProduct.zProductDocument(id, title,database,urlupdate)
    ob.title=title
    id=self._setObject(id, ob)
    if REQUEST is not None:
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        if submit=="Add and edit": u=u+"/"+str(id)+"/manage_opt"
	else: u=u+"/manage_main"
        REQUEST.RESPONSE.redirect(u)
    return 'Nothing'




# Load images from disk and make them accessible
misc_={
       'icon':   ImageFile('img/icon.png',globals()),
      }  




def initialize(context): 
    """Initialize the product."""  
    try: 
        context.registerClass(
            zProduct.zProductDocument,
            #permission='Add product', #automatically included; I don't need to specify it
            constructors = (                 
                manage_addzProductForm,  #html file; html-form has action next constructor
                manage_addzProduct),     #constructor caled from html-form (action)                                            
            )
        context.registerBaseClass(zProduct.zProductDocument)

    except:
        import sys, traceback, string
        type, val, tb = sys.exc_info()
        sys.stderr.write(string.join(traceback.format_exception(type, val, tb), ''))
        del type, val, tb

    context.registerHelp()
    context.registerHelpTitle(zProduct.ProductName)
